"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from ...models.components import client as components_client
from dataclasses_json import Undefined, dataclass_json
from formancesdkauth import utils


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ClientsCreateResponseBody:
    r"""The request has succeeded and a new resource has been created as a result."""
    data: components_client.Client = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('data') }})
    

